@@ -12,7 +12,7 @@ def parse_arguments():
         "username",
         action="store",
         nargs="*",
-        help="Atleast one or more usernames to download stories for.",
+        help="At least one or more usernames to download stories for.",
     )
 
     any_one_group = parser.add_mutually_exclusive_group()
@@ -21,7 +21,7 @@ def parse_arguments():
         "--scan-clipboard",
         action="store_true",
         help="Scan clipboard for story links"
-        " with the format of 'https://story.snapchat.com/s/<username>'",
+        " ('https://story.snapchat.com/<s>/<username>').",
         dest="scan_clipboard",
     )
 
@@ -38,7 +38,7 @@ def parse_arguments():
         "--batch-file",
         action="store",
         default=None,
-        help="Read usernames from file",
+        help="Read usernames from batch file (one username per line).",
         metavar="BATCH_FILENAME",
         dest="batch_file",
     )
@@ -48,7 +48,7 @@ def parse_arguments():
         "--directory-prefix",
         action="store",
         default=os.path.abspath(os.getcwd()),
-        help="Directory Prefix for downloading stories",
+        help="Location to store downloaded media.",
         metavar="DIRECTORY_PREFIX",
         dest="save_prefix",
     )
@@ -61,13 +61,21 @@ def parse_arguments():
         dest="scan_prefix",
     )
 
+    parser.add_argument(
+        "-d",
+        "--dump-json",
+        action="store_true",
+        help="Save metadata to a JSON file next to downloaded videos/pictures.",
+        dest="dump_json",
+    )
+
     parser.add_argument(
         "-l",
-        "--limit-story-count",
+        "--limit-story",
         action="store",
         default=-1,
         help="Set maximum number of stories to download.",
-        metavar="NUM_STORY",
+        metavar="MAX_NUM_STORY",
         dest="limit_story",
         type=int,
     )
@@ -88,7 +96,7 @@ def parse_arguments():
         "--update-interval",
         action="store",
         default=60 * 10,
-        help="Set the update interval for new story in seconds. (Default: 10m)",
+        help="Set the update interval for checking new story in seconds. (Default: 10m)",
         metavar="INTERVAL",
         dest="interval",
         type=int,
@@ -108,7 +116,7 @@ def parse_arguments():
         "-q",
         "--quiet",
         action="store_true",
-        help="Do not print anything to the console. (errors are still logged)",
+        help="Do not print anything except errors to the console.",
     )
 
     if len(sys.argv) == 1:
